/*
 * Copyright 2010-2012 Craig S. Dickson (http://craigsdickson.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.squeakysand.jsp.taglib.lang;

import com.squeakysand.commons.lang.NullParameterException;
import com.squeakysand.jsp.tagext.annotations.JspElFunction;

/**
 * A collection of functions for use in EL expressions that relate to classes in the {@link java.lang} package.
 * 
 * @author <a href="http://craigsdickson.com">Craig S. Dickson</a>
 */
public class Functions {

    /**
     * Allows access to the {@link Class} of an object from within an EL expression.
     *
     * @param o the target object.
     * @return the {@link Class} of the target object.
     */
    @JspElFunction
    public static Class<?> getClass(Object o) {
        if (o == null) {
            throw new NullParameterException("o");
        }
        Class<?> result = null;
        if (o != null) {
            result = o.getClass();
        }
        return result;
    }

}
