/*
 * Copyright 2010-2012 Craig S. Dickson (http://craigsdickson.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.squeakysand.jsp.taglib.logging;

import com.squeakysand.jsp.tagext.EnhancedSimpleTagSupport;
import com.squeakysand.jsp.tagext.VariableScope;
import com.squeakysand.jsp.tagext.annotations.JspTag;
import com.squeakysand.jsp.tagext.annotations.JspTagAttribute;
import com.squeakysand.jsp.tagext.annotations.JspTagVariable;

import javax.servlet.jsp.JspException;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Injects a {@link Level} instance into the page context to be used by <code>log</code> tags later in the page.
 * 
 * @author <a href="http://craigsdickson.com">Craig S. Dickson</a>
 */
@JspTag(name = "setLogLevel")
public class SetLoggerLevelTag extends EnhancedSimpleTagSupport {

    private static final Logger LOG = LoggerFactory.getLogger(SetLoggerLevelTag.class);

    @JspTagVariable(scope = VariableScope.AT_END, variableClass = Level.class)
    public static final String LOGGER_LEVEL_ATTRIBUTE = "com.squeakysand.taglib.logging.SetLoggerLevelTag.LOGGER_LEVEL_ATTRIBUTE";

    private Level level;

    @Override
    public void doTag() throws JspException {
        validateNotNullAttribute("level", level);
        LOG.debug("setting log level to: {}", level);
        setPageAttribute(LOGGER_LEVEL_ATTRIBUTE, level);
    }

    /**
     * Accessor for the <code>level</code> property.
     * 
     * @return the current value of the <code>level</code> property.
     */
    public Level getLevel() {
        return level;
    }

    /**
     * The level to use for <code>log</code> tags later in the page that do not have a level explicitly set.
     * 
     * @param level
     *            the level to use.
     */
    @JspTagAttribute(required = true, rtexprvalue = true)
    public void setLevel(Level level) {
        level = level;
    }

}
