/*
 * Copyright 2010-2012 Craig S. Dickson (http://craigsdickson.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.squeakysand.jsp.taglib.logging;

import com.squeakysand.jsp.tagext.EnhancedSimpleTagSupport;
import com.squeakysand.jsp.tagext.VariableScope;
import com.squeakysand.jsp.tagext.annotations.JspTag;
import com.squeakysand.jsp.tagext.annotations.JspTagAttribute;
import com.squeakysand.jsp.tagext.annotations.JspTagVariable;

import javax.servlet.jsp.JspException;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Injects a {@link String} logger name into the page context to be used by <code>log</code> tags later in the page.
 * 
 * @author <a href="http://craigsdickson.com">Craig S. Dickson</a>
 */
@JspTag(name = "setLogName")
public class SetLoggerNameTag extends EnhancedSimpleTagSupport {

    private static final Logger LOG = LoggerFactory.getLogger(SetLoggerNameTag.class);

    @JspTagVariable(scope = VariableScope.AT_END)
    public static final String LOGGER_NAME_ATTRIBUTE = "com.squeakysand.taglib.logging.SetLoggerNameTag.LOGGER_NAME_ATTRIBUTE";

    private String name;

    @Override
    public void doTag() throws JspException {
        validateNotNullOrEmptyAttribute("name", name);
        setPageAttribute(LOGGER_NAME_ATTRIBUTE, name);
    }

    /**
     * Accessor for the <code>name</code> property.
     * 
     * @return the current value of the <code>name</code> property.
     */
    public String getName() {
        return name;
    }

    /**
     * The name of the logger to use for <code>log</code> tags later in the page that do not have a name explicitly set.
     * 
     * @param name the name of the logger to user.
     */
    @JspTagAttribute(required = true, rtexprvalue = true)
    public void setName(String name) {
        this.name = name;
    }

}
